@@ -9,6 +9,7 @@
  */
 namespace PHPUnit\Event;
 
+use const PHP_VERSION;
 use function array_map;
 use function array_values;
 use function explode;
@@ -20,8 +21,6 @@ use PHPUnit\Event\Code\TestDoxBuilder;
 use PHPUnit\Event\Code\ThrowableBuilder;
 use PHPUnit\Event\Telemetry\Php81GarbageCollectorStatusProvider;
 use PHPUnit\Event\Telemetry\Php83GarbageCollectorStatusProvider;
-use PHPUnit\Event\Test\AssertionFailed;
-use PHPUnit\Event\Test\AssertionSucceeded;
 use PHPUnit\Event\TestData\TestDataCollection;
 use PHPUnit\Event\TestRunner\ExecutionStarted;
 use PHPUnit\Event\TestRunner\ExecutionStartedSubscriber;
@@ -39,7 +38,6 @@ use PHPUnit\Framework\Attributes\CoversClass;
 use PHPUnit\Metadata\MetadataCollection;
 use PHPUnit\TestFixture;
 use PHPUnit\TestFixture\RecordingSubscriber;
-use SebastianBergmann\Exporter\Exporter;
 use stdClass;
 
 #[CoversClass(DispatchingEmitter::class)]
@@ -103,157 +101,6 @@ final class DispatchingEmitterTest extends Framework\TestCase
         $this->assertInstanceOf(TestRunner\Finished::class, $subscriber->lastRecordedEvent());
     }
 
-    public function testAssertionSucceededDoesNotDispatchAssertionSucceededEventWhenItDoesNotHaveSubscriber(): void
-    {
-        $value      = 'value';
-        $constraint = new Framework\Constraint\IsEqual('Ok');
-        $message    = 'message';
-
-        $dispatcher = $this->createMock(SubscribableDispatcher::class);
-
-        $dispatcher
-            ->expects($this->once())
-            ->method('hasSubscriberFor')
-            ->with($this->identicalTo(AssertionSucceeded::class))
-            ->willReturn(false);
-
-        $dispatcher
-            ->expects($this->never())
-            ->method('dispatch');
-
-        $telemetrySystem = $this->telemetrySystem();
-
-        $emitter = new DispatchingEmitter(
-            $dispatcher,
-            $telemetrySystem,
-        );
-
-        $emitter->testAssertionSucceeded(
-            $value,
-            $constraint,
-            $message,
-        );
-    }
-
-    public function testAssertionSucceededDispatchesAssertionSucceededEventWhenItHasSubscriber(): void
-    {
-        $value      = 'value';
-        $constraint = new Framework\Constraint\IsEqual('Ok');
-        $message    = 'message';
-
-        $subscriber = new class extends RecordingSubscriber implements Test\AssertionSucceededSubscriber
-        {
-            public function notify(Test\AssertionSucceeded $event): void
-            {
-                $this->record($event);
-            }
-        };
-
-        $dispatcher = $this->dispatcherWithRegisteredSubscriber(
-            Test\AssertionSucceededSubscriber::class,
-            Test\AssertionSucceeded::class,
-            $subscriber,
-        );
-
-        $telemetrySystem = $this->telemetrySystem();
-
-        $emitter = new DispatchingEmitter(
-            $dispatcher,
-            $telemetrySystem,
-        );
-
-        $emitter->testAssertionSucceeded(
-            $value,
-            $constraint,
-            $message,
-        );
-
-        $this->assertSame(1, $subscriber->recordedEventCount());
-
-        $event = $subscriber->lastRecordedEvent();
-
-        $this->assertInstanceOf(Test\AssertionSucceeded::class, $event);
-
-        $this->assertSame(1, $event->count());
-        $this->assertSame($message, $event->message());
-    }
-
-    public function testAssertionFailedDoesNotDispatchAssertionFailedEventWhenItDoesNotHaveSubscriber(): void
-    {
-        $value      = 'value';
-        $constraint = new Framework\Constraint\IsEqual('Ok');
-        $message    = 'message';
-
-        $dispatcher = $this->createMock(SubscribableDispatcher::class);
-
-        $dispatcher
-            ->expects($this->once())
-            ->method('hasSubscriberFor')
-            ->with($this->identicalTo(AssertionFailed::class))
-            ->willReturn(false);
-
-        $dispatcher
-            ->expects($this->never())
-            ->method('dispatch');
-
-        $telemetrySystem = $this->telemetrySystem();
-
-        $emitter = new DispatchingEmitter(
-            $dispatcher,
-            $telemetrySystem,
-        );
-
-        $emitter->testAssertionFailed(
-            $value,
-            $constraint,
-            $message,
-        );
-    }
-
-    public function testAssertionFailedDispatchesAssertionFailedEventWhenItHasSubscriber(): void
-    {
-        $value      = 'value';
-        $constraint = new Framework\Constraint\IsEqual('Ok');
-        $message    = 'message';
-
-        $subscriber = new class extends RecordingSubscriber implements Test\AssertionFailedSubscriber
-        {
-            public function notify(Test\AssertionFailed $event): void
-            {
-                $this->record($event);
-            }
-        };
-
-        $dispatcher = $this->dispatcherWithRegisteredSubscriber(
-            Test\AssertionFailedSubscriber::class,
-            Test\AssertionFailed::class,
-            $subscriber,
-        );
-
-        $telemetrySystem = $this->telemetrySystem();
-
-        $emitter = new DispatchingEmitter(
-            $dispatcher,
-            $telemetrySystem,
-        );
-
-        $emitter->testAssertionFailed(
-            $value,
-            $constraint,
-            $message,
-        );
-
-        $this->assertSame(1, $subscriber->recordedEventCount());
-
-        $event = $subscriber->lastRecordedEvent();
-
-        $this->assertInstanceOf(Test\AssertionFailed::class, $event);
-
-        $this->assertSame((new Exporter)->export('value'), $event->value());
-        $this->assertSame(1, $event->count());
-        $this->assertSame($message, $event->message());
-    }
-
     public function testBootstrapFinishedDispatchesBootstrapFinishedEvent(): void
     {
         $filename = __FILE__;
@@ -1473,7 +1320,7 @@ final class DispatchingEmitterTest extends Framework\TestCase
         $this->assertInstanceOf(Test\TestProxyCreated::class, $event);
 
         $this->assertSame($className, $event->className());
-        $this->assertSame("Array &0 (\n    0 => 'foo'\n)", $event->constructorArguments());
+        $this->assertSame("Array &0 [\n    0 => 'foo',\n]", $event->constructorArguments());
     }
 
     public function testTestTestStubCreatedDispatchesTestDoubleTestStubCreatedEvent(): void
