@@ -1053,16 +1053,41 @@ XML;
         );
     }
 
-    public function testAssertThatContains(): void
+    public function testAssertThatContainsEqual(): void
+    {
+        $this->assertThat(['foo'], $this->containsEqual('foo'));
+    }
+
+    public function testAssertThatContainsIdentical(): void
     {
         $this->assertThat(['foo'], $this->containsIdentical('foo'));
     }
 
+    public function testAssertThatStringMatchesFormatDescription(): void
+    {
+        $this->assertThat('foo', $this->matches('%s'));
+    }
+
     public function testAssertThatStringContains(): void
     {
         $this->assertThat('barfoobar', $this->stringContains('foo'));
     }
 
+    public function testAssertThatStringStartsWith(): void
+    {
+        $this->assertThat('foobar', $this->stringStartsWith('foo'));
+    }
+
+    public function testAssertThatStringEndsWith(): void
+    {
+        $this->assertThat('foobar', $this->stringEndsWith('bar'));
+    }
+
+    public function testAssertThatStringEqualsStringIgnoringLineEndings(): void
+    {
+        $this->assertThat('foo' . "\r\n", $this->stringEqualsStringIgnoringLineEndings('foo' . "\n"));
+    }
+
     public function testAssertThatContainsOnly(): void
     {
         $this->assertThat(['foo'], $this->containsOnly('string'));
@@ -1088,6 +1113,21 @@ XML;
         $this->assertThat('foo', $this->equalTo('foo'));
     }
 
+    public function testAssertThatEqualToCanonicalizing(): void
+    {
+        $this->assertThat(['foo', 'bar'], $this->equalToCanonicalizing(['bar', 'foo']));
+    }
+
+    public function testAssertThatEqualToIgnoringCase(): void
+    {
+        $this->assertThat('foo', $this->equalToIgnoringCase('FOO'));
+    }
+
+    public function testAssertThatEqualToWithDelta(): void
+    {
+        $this->assertThat(1.0, $this->equalToWithDelta(1.09, 0.1));
+    }
+
     public function testAssertThatIdenticalTo(): void
     {
         $value      = new stdClass;
@@ -1111,6 +1151,21 @@ XML;
         $this->assertThat([], $this->isEmpty());
     }
 
+    public function testAssertThatFileIsReadable(): void
+    {
+        $this->assertThat(__FILE__, $this->isReadable());
+    }
+
+    public function testAssertThatFileIsWritable(): void
+    {
+        $this->assertThat(__FILE__, $this->isWritable());
+    }
+
+    public function testAssertThatDirectoryExists(): void
+    {
+        $this->assertThat(__DIR__, $this->directoryExists());
+    }
+
     public function testAssertThatFileExists(): void
     {
         $this->assertThat(__FILE__, $this->fileExists());
@@ -1184,6 +1239,21 @@ XML;
         );
     }
 
+    public function testAssertFileNotEqualsCanonicalizing(): void
+    {
+        $this->assertFileNotEqualsCanonicalizing(
+            TEST_FILES_PATH . 'foo.xml',
+            TEST_FILES_PATH . 'bar.xml',
+        );
+
+        $this->expectException(AssertionFailedError::class);
+
+        $this->assertFileNotEqualsCanonicalizing(
+            TEST_FILES_PATH . 'foo.xml',
+            TEST_FILES_PATH . 'foo.xml',
+        );
+    }
+
     public function testAssertStringEqualsFile(): void
     {
         $this->assertStringEqualsFile(
@@ -1707,6 +1777,16 @@ XML;
         $this->assertFileEqualsCanonicalizing(TEST_FILES_PATH . 'foo.txt', TEST_FILES_PATH . 'foo.xml');
     }
 
+    public function testAssertStringEqualsFileCanonicalizing(): void
+    {
+        $contents = file_get_contents(TEST_FILES_PATH . 'foo.txt');
+
+        $this->assertStringEqualsFileCanonicalizing(TEST_FILES_PATH . 'foo.txt', $contents);
+
+        $this->expectException(AssertionFailedError::class);
+        $this->assertStringEqualsFileCanonicalizing(TEST_FILES_PATH . 'foo.txt', $contents . 'BAR');
+    }
+
     public function testAssertStringNotEqualsFileCanonicalizing(): void
     {
         $contents = file_get_contents(TEST_FILES_PATH . 'foo.xml');
