@@ -36,6 +36,17 @@ final class LogicalOrTest extends TestCase
                 true,
             ],
 
+            [
+                true,
+                'is of type boolean or is equal to true',
+                '',
+                self::logicalOr(
+                    self::isType('boolean'),
+                    true,
+                ),
+                true,
+            ],
+
             [
                 true,
                 'is true or is of type boolean and is false',
@@ -88,7 +99,7 @@ final class LogicalOrTest extends TestCase
     {
         $constraint = $this->logicalOr(
             $this->isType('bool'),
-            $this->isTrue(),
+            true,
         );
 
         $this->assertCount(2, $constraint);
