@@ -10,6 +10,7 @@
 namespace PHPUnit\Metadata;
 
 use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\Group;
 use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\Attributes\UsesClass;
 use PHPUnit\Framework\TestCase;
@@ -25,18 +26,17 @@ use PHPUnit\Util\VersionComparisonOperator;
 #[UsesClass(Before::class)]
 #[UsesClass(BeforeClass::class)]
 #[UsesClass(Covers::class)]
-#[UsesClass(\PHPUnit\Metadata\CoversClass::class)]
+#[UsesClass(CoversClass::class)]
 #[UsesClass(CoversDefaultClass::class)]
 #[UsesClass(CoversFunction::class)]
+#[UsesClass(CoversMethod::class)]
 #[UsesClass(CoversNothing::class)]
 #[UsesClass(DataProvider::class)]
 #[UsesClass(DependsOnClass::class)]
 #[UsesClass(DependsOnMethod::class)]
+#[UsesClass(DisableReturnValueGenerationForTestDoubles::class)]
 #[UsesClass(DoesNotPerformAssertions::class)]
 #[UsesClass(Group::class)]
-#[UsesClass(IgnoreClassForCodeCoverage::class)]
-#[UsesClass(IgnoreMethodForCodeCoverage::class)]
-#[UsesClass(IgnoreFunctionForCodeCoverage::class)]
 #[UsesClass(Metadata::class)]
 #[UsesClass(PostCondition::class)]
 #[UsesClass(PreCondition::class)]
@@ -56,10 +56,11 @@ use PHPUnit\Util\VersionComparisonOperator;
 #[UsesClass(TestDox::class)]
 #[UsesClass(TestWith::class)]
 #[UsesClass(Uses::class)]
-#[UsesClass(\PHPUnit\Metadata\UsesClass::class)]
+#[UsesClass(UsesClass::class)]
 #[UsesClass(UsesDefaultClass::class)]
 #[UsesClass(UsesFunction::class)]
 #[Small]
+#[Group('metadata')]
 final class MetadataCollectionTest extends TestCase
 {
     public function testCanBeEmpty(): void
@@ -103,8 +104,8 @@ final class MetadataCollectionTest extends TestCase
 
     public function testCanBeMerged(): void
     {
-        $a = MetadataCollection::fromArray([Metadata::before()]);
-        $b = MetadataCollection::fromArray([Metadata::after()]);
+        $a = MetadataCollection::fromArray([Metadata::before(0)]);
+        $b = MetadataCollection::fromArray([Metadata::after(0)]);
         $c = $a->mergeWith($b);
 
         $this->assertCount(2, $c);
@@ -202,6 +203,14 @@ final class MetadataCollectionTest extends TestCase
         $this->assertTrue($collection->asArray()[0]->isCoversDefaultClass());
     }
 
+    public function test_Can_be_filtered_for_CoversTrait(): void
+    {
+        $collection = $this->collectionWithOneOfEach()->isCoversTrait();
+
+        $this->assertCount(1, $collection);
+        $this->assertTrue($collection->asArray()[0]->isCoversTrait());
+    }
+
     public function test_Can_be_filtered_for_CoversFunction(): void
     {
         $collection = $this->collectionWithOneOfEach()->isCoversFunction();
@@ -210,6 +219,14 @@ final class MetadataCollectionTest extends TestCase
         $this->assertTrue($collection->asArray()[0]->isCoversFunction());
     }
 
+    public function test_Can_be_filtered_for_CoversMethod(): void
+    {
+        $collection = $this->collectionWithOneOfEach()->isCoversMethod();
+
+        $this->assertCount(1, $collection);
+        $this->assertTrue($collection->asArray()[0]->isCoversMethod());
+    }
+
     public function test_Can_be_filtered_for_CoversNothing(): void
     {
         $collection = $this->collectionWithOneOfEach()->isCoversNothing();
@@ -251,6 +268,14 @@ final class MetadataCollectionTest extends TestCase
         $this->assertTrue($collection->asArray()[0]->isDependsOnMethod());
     }
 
+    public function test_Can_be_filtered_for_DisableReturnValueGenerationForTestDoubles(): void
+    {
+        $collection = $this->collectionWithOneOfEach()->isDisableReturnValueGenerationForTestDoubles();
+
+        $this->assertCount(1, $collection);
+        $this->assertTrue($collection->asArray()[0]->isDisableReturnValueGenerationForTestDoubles());
+    }
+
     public function test_Can_be_filtered_for_DoesNotPerformAssertions(): void
     {
         $collection = $this->collectionWithOneOfEach()->isDoesNotPerformAssertions();
@@ -283,28 +308,20 @@ final class MetadataCollectionTest extends TestCase
         $this->assertTrue($collection->asArray()[0]->isGroup());
     }
 
-    public function test_Can_be_filtered_for_IgnoreClassForCodeCoverage(): void
+    public function test_Can_be_filtered_for_IgnoreDeprecations(): void
     {
-        $collection = $this->collectionWithOneOfEach()->isIgnoreClassForCodeCoverage();
+        $collection = $this->collectionWithOneOfEach()->isIgnoreDeprecations();
 
         $this->assertCount(1, $collection);
-        $this->assertTrue($collection->asArray()[0]->isIgnoreClassForCodeCoverage());
+        $this->assertTrue($collection->asArray()[0]->isIgnoreDeprecations());
     }
 
-    public function test_Can_be_filtered_for_IgnoreMethodForCodeCoverage(): void
+    public function test_Can_be_filtered_for_IgnorePhpunitDeprecations(): void
     {
-        $collection = $this->collectionWithOneOfEach()->isIgnoreMethodForCodeCoverage();
+        $collection = $this->collectionWithOneOfEach()->isIgnorePhpunitDeprecations();
 
         $this->assertCount(1, $collection);
-        $this->assertTrue($collection->asArray()[0]->isIgnoreMethodForCodeCoverage());
-    }
-
-    public function test_Can_be_filtered_for_IgnoreFunctionForCodeCoverage(): void
-    {
-        $collection = $this->collectionWithOneOfEach()->isIgnoreFunctionForCodeCoverage();
-
-        $this->assertCount(1, $collection);
-        $this->assertTrue($collection->asArray()[0]->isIgnoreFunctionForCodeCoverage());
+        $this->assertTrue($collection->asArray()[0]->isIgnorePhpunitDeprecations());
     }
 
     public function test_Can_be_filtered_for_PostCondition(): void
@@ -467,6 +484,14 @@ final class MetadataCollectionTest extends TestCase
         $this->assertTrue($collection->asArray()[0]->isUsesDefaultClass());
     }
 
+    public function test_Can_be_filtered_for_UsesTrait(): void
+    {
+        $collection = $this->collectionWithOneOfEach()->isUsesTrait();
+
+        $this->assertCount(1, $collection);
+        $this->assertTrue($collection->asArray()[0]->isUsesTrait());
+    }
+
     public function test_Can_be_filtered_for_UsesFunction(): void
     {
         $collection = $this->collectionWithOneOfEach()->isUsesFunction();
@@ -475,6 +500,14 @@ final class MetadataCollectionTest extends TestCase
         $this->assertTrue($collection->asArray()[0]->isUsesFunction());
     }
 
+    public function test_Can_be_filtered_for_UsesMethod(): void
+    {
+        $collection = $this->collectionWithOneOfEach()->isUsesMethod();
+
+        $this->assertCount(1, $collection);
+        $this->assertTrue($collection->asArray()[0]->isUsesMethod());
+    }
+
     public function test_Can_be_filtered_for_WithoutErrorHandler(): void
     {
         $collection = $this->collectionWithOneOfEach()->isWithoutErrorHandler();
@@ -487,29 +520,31 @@ final class MetadataCollectionTest extends TestCase
     {
         return MetadataCollection::fromArray(
             [
-                Metadata::afterClass(),
-                Metadata::after(),
+                Metadata::afterClass(0),
+                Metadata::after(0),
                 Metadata::backupGlobalsOnClass(true),
                 Metadata::backupStaticPropertiesOnClass(true),
-                Metadata::beforeClass(),
-                Metadata::before(),
+                Metadata::beforeClass(0),
+                Metadata::before(0),
                 Metadata::coversOnClass(''),
                 Metadata::coversClass(''),
                 Metadata::coversDefaultClass(''),
+                Metadata::coversTrait(''),
                 Metadata::coversFunction(''),
+                Metadata::coversMethod('', ''),
                 Metadata::coversNothingOnClass(),
                 Metadata::dataProvider('', ''),
                 Metadata::dependsOnClass('', false, false),
                 Metadata::dependsOnMethod('', '', false, false),
+                Metadata::disableReturnValueGenerationForTestDoubles(),
                 Metadata::doesNotPerformAssertionsOnClass(),
                 Metadata::excludeGlobalVariableFromBackupOnClass(''),
                 Metadata::excludeStaticPropertyFromBackupOnClass('', ''),
                 Metadata::groupOnClass(''),
-                Metadata::ignoreClassForCodeCoverage(''),
-                Metadata::ignoreMethodForCodeCoverage('', ''),
-                Metadata::ignoreFunctionForCodeCoverage(''),
-                Metadata::postCondition(),
-                Metadata::preCondition(),
+                Metadata::ignoreDeprecationsOnClass(),
+                Metadata::ignorePhpunitDeprecationsOnClass(),
+                Metadata::postCondition(0),
+                Metadata::preCondition(0),
                 Metadata::preserveGlobalStateOnClass(true),
                 Metadata::requiresMethodOnClass('', ''),
                 Metadata::requiresFunctionOnClass(''),
@@ -538,7 +573,9 @@ final class MetadataCollectionTest extends TestCase
                 Metadata::usesOnClass(''),
                 Metadata::usesClass(''),
                 Metadata::usesDefaultClass(''),
+                Metadata::usesTrait(''),
                 Metadata::usesFunction(''),
+                Metadata::usesMethod('', ''),
                 Metadata::withoutErrorHandler(),
             ],
         );
