@@ -14,6 +14,10 @@ use PHPUnit\Framework\Attributes\TestDox;
 use PHPUnit\Framework\TestCase;
 use PHPUnit\Metadata\DependsOnClass;
 use PHPUnit\Metadata\DependsOnMethod;
+use PHPUnit\Metadata\RequiresPhp;
+use PHPUnit\Metadata\RequiresPhpExtension;
+use PHPUnit\Metadata\RequiresPhpunit;
+use PHPUnit\Metadata\RequiresSetting;
 use PHPUnit\Metadata\Version\ComparisonRequirement;
 use PHPUnit\Metadata\Version\ConstraintRequirement;
 use PHPUnit\TestFixture\Metadata\Attribute\AnotherTest;
@@ -21,10 +25,15 @@ use PHPUnit\TestFixture\Metadata\Attribute\BackupGlobalsTest;
 use PHPUnit\TestFixture\Metadata\Attribute\BackupStaticPropertiesTest;
 use PHPUnit\TestFixture\Metadata\Attribute\CoversTest;
 use PHPUnit\TestFixture\Metadata\Attribute\DependencyTest;
+use PHPUnit\TestFixture\Metadata\Attribute\DisableReturnValueGenerationForTestDoublesTest;
 use PHPUnit\TestFixture\Metadata\Attribute\DoesNotPerformAssertionsTest;
 use PHPUnit\TestFixture\Metadata\Attribute\Example;
+use PHPUnit\TestFixture\Metadata\Attribute\ExampleTrait;
 use PHPUnit\TestFixture\Metadata\Attribute\GroupTest;
-use PHPUnit\TestFixture\Metadata\Attribute\IgnoreCodeCoverageTest;
+use PHPUnit\TestFixture\Metadata\Attribute\IgnoreDeprecationsClassTest;
+use PHPUnit\TestFixture\Metadata\Attribute\IgnoreDeprecationsMethodTest;
+use PHPUnit\TestFixture\Metadata\Attribute\IgnorePhpunitDeprecationsClassTest;
+use PHPUnit\TestFixture\Metadata\Attribute\IgnorePhpunitDeprecationsMethodTest;
 use PHPUnit\TestFixture\Metadata\Attribute\LargeTest;
 use PHPUnit\TestFixture\Metadata\Attribute\MediumTest;
 use PHPUnit\TestFixture\Metadata\Attribute\NonPhpunitAttributeTest;
@@ -76,6 +85,16 @@ abstract class AttributeParserTestCase extends TestCase
         $this->assertSame(Example::class, $metadata->asArray()[0]->className());
     }
 
+    #[TestDox('Parses #[CoversTrait] attribute on class')]
+    public function test_parses_CoversTrait_attribute_on_class(): void
+    {
+        $metadata = $this->parser()->forClass(CoversTest::class)->isCoversTrait();
+
+        $this->assertCount(1, $metadata);
+        $this->assertTrue($metadata->asArray()[0]->isCoversTrait());
+        $this->assertSame(ExampleTrait::class, $metadata->asArray()[0]->traitName());
+    }
+
     #[TestDox('Parses #[CoversFunction] attribute on class')]
     public function test_parses_CoversFunction_attribute_on_class(): void
     {
@@ -86,6 +105,17 @@ abstract class AttributeParserTestCase extends TestCase
         $this->assertSame('f', $metadata->asArray()[0]->functionName());
     }
 
+    #[TestDox('Parses #[CoversMethod] attribute on class')]
+    public function test_parses_CoversMethod_attribute_on_class(): void
+    {
+        $metadata = $this->parser()->forClass(CoversTest::class)->isCoversMethod();
+
+        $this->assertCount(1, $metadata);
+        $this->assertTrue($metadata->asArray()[0]->isCoversMethod());
+        $this->assertSame(Example::class, $metadata->asArray()[0]->className());
+        $this->assertSame('method', $metadata->asArray()[0]->methodName());
+    }
+
     #[TestDox('Parses #[CoversNothing] attribute on class')]
     public function test_parses_CoversNothing_attribute_on_class(): void
     {
@@ -95,6 +125,15 @@ abstract class AttributeParserTestCase extends TestCase
         $this->assertTrue($metadata->asArray()[0]->isCoversNothing());
     }
 
+    #[TestDox('Parses #[DisableReturnValueGenerationForTestDoubles] attribute on class')]
+    public function test_parses_DisableReturnValueGenerationForTestDoubles_attribute_on_class(): void
+    {
+        $metadata = $this->parser()->forClass(DisableReturnValueGenerationForTestDoublesTest::class)->isDisableReturnValueGenerationForTestDoubles();
+
+        $this->assertCount(1, $metadata);
+        $this->assertTrue($metadata->asArray()[0]->isDisableReturnValueGenerationForTestDoubles());
+    }
+
     #[TestDox('Parses #[DoesNotPerformAssertions] attribute on class')]
     public function test_parses_DoesNotPerformAssertions_attribute_on_class(): void
     {
@@ -155,35 +194,22 @@ abstract class AttributeParserTestCase extends TestCase
         $this->assertSame('medium', $metadata->asArray()[0]->groupName());
     }
 
-    #[TestDox('Parses #[IgnoreClassForCodeCoverage] attribute on class')]
-    public function test_parses_IgnoreClassForCodeCoverage_attribute_on_class(): void
+    #[TestDox('Parses #[IgnoreDeprecations] attribute on class')]
+    public function test_parses_IgnoreDeprecations_attribute_on_class(): void
     {
-        $metadata = $this->parser()->forClass(IgnoreCodeCoverageTest::class)->isIgnoreClassForCodeCoverage();
+        $metadata = $this->parser()->forClass(IgnoreDeprecationsClassTest::class)->isIgnoreDeprecations();
 
         $this->assertCount(1, $metadata);
-        $this->assertTrue($metadata->asArray()[0]->isIgnoreClassForCodeCoverage());
-        $this->assertSame('className', $metadata->asArray()[0]->className());
+        $this->assertTrue($metadata->asArray()[0]->isIgnoreDeprecations());
     }
 
-    #[TestDox('Parses #[IgnoreMethodForCodeCoverage] attribute on class')]
-    public function test_parses_IgnoreMethodForCodeCoverage_attribute_on_class(): void
+    #[TestDox('Parses #[IgnorePhpunitDeprecations] attribute on class')]
+    public function test_parses_IgnorePhpunitDeprecations_attribute_on_class(): void
     {
-        $metadata = $this->parser()->forClass(IgnoreCodeCoverageTest::class)->isIgnoreMethodForCodeCoverage();
+        $metadata = $this->parser()->forClass(IgnorePhpunitDeprecationsClassTest::class)->isIgnorePhpunitDeprecations();
 
         $this->assertCount(1, $metadata);
-        $this->assertTrue($metadata->asArray()[0]->isIgnoreMethodForCodeCoverage());
-        $this->assertSame('ClassName', $metadata->asArray()[0]->className());
-        $this->assertSame('methodName', $metadata->asArray()[0]->methodName());
-    }
-
-    #[TestDox('Parses #[IgnoreFunctionForCodeCoverage] attribute on class')]
-    public function test_parses_IgnoreFunctionForCodeCoverage_attribute_on_class(): void
-    {
-        $metadata = $this->parser()->forClass(IgnoreCodeCoverageTest::class)->isIgnoreFunctionForCodeCoverage();
-
-        $this->assertCount(1, $metadata);
-        $this->assertTrue($metadata->asArray()[0]->isIgnoreFunctionForCodeCoverage());
-        $this->assertSame('functionName', $metadata->asArray()[0]->functionName());
+        $this->assertTrue($metadata->asArray()[0]->isIgnorePhpunitDeprecations());
     }
 
     #[TestDox('Parses #[PreserveGlobalState] attribute on class')]
@@ -248,7 +274,7 @@ abstract class AttributeParserTestCase extends TestCase
 
         $this->assertTrue($requirement->isRequiresPhp());
 
-        assert($requirement instanceof \PHPUnit\Metadata\RequiresPhp);
+        assert($requirement instanceof RequiresPhp);
 
         $versionRequirement = $requirement->versionRequirement();
 
@@ -280,7 +306,7 @@ abstract class AttributeParserTestCase extends TestCase
 
         $this->assertTrue($requirement->isRequiresPhpunit());
 
-        assert($requirement instanceof \PHPUnit\Metadata\RequiresPhpunit);
+        assert($requirement instanceof RequiresPhpunit);
 
         $versionRequirement = $requirement->versionRequirement();
 
@@ -300,7 +326,7 @@ abstract class AttributeParserTestCase extends TestCase
 
         $this->assertTrue($requirement->isRequiresSetting());
 
-        assert($requirement instanceof \PHPUnit\Metadata\RequiresSetting);
+        assert($requirement instanceof RequiresSetting);
 
         $this->assertSame('setting', $requirement->setting());
         $this->assertSame('value', $requirement->value());
@@ -364,6 +390,16 @@ abstract class AttributeParserTestCase extends TestCase
         $this->assertSame(Example::class, $metadata->asArray()[0]->className());
     }
 
+    #[TestDox('Parses #[UsesTrait] attribute on class')]
+    public function test_parses_UsesTrait_attribute_on_class(): void
+    {
+        $metadata = $this->parser()->forClass(UsesTest::class)->isUsesTrait();
+
+        $this->assertCount(1, $metadata);
+        $this->assertTrue($metadata->asArray()[0]->isUsesTrait());
+        $this->assertSame(ExampleTrait::class, $metadata->asArray()[0]->traitName());
+    }
+
     #[TestDox('Parses #[UsesFunction] attribute on class')]
     public function test_parses_UsesFunction_attribute_on_class(): void
     {
@@ -374,6 +410,17 @@ abstract class AttributeParserTestCase extends TestCase
         $this->assertSame('f', $metadata->asArray()[0]->functionName());
     }
 
+    #[TestDox('Parses #[UsesMethod] attribute on class')]
+    public function test_parses_UsesMethod_attribute_on_class(): void
+    {
+        $metadata = $this->parser()->forClass(UsesTest::class)->isUsesMethod();
+
+        $this->assertCount(1, $metadata);
+        $this->assertTrue($metadata->asArray()[0]->isUsesMethod());
+        $this->assertSame(Example::class, $metadata->asArray()[0]->className());
+        $this->assertSame('method', $metadata->asArray()[0]->methodName());
+    }
+
     #[TestDox('Parses #[After] attribute on class')]
     public function test_parses_After_attribute_on_method(): void
     {
@@ -651,6 +698,24 @@ abstract class AttributeParserTestCase extends TestCase
         $this->assertSame('another-group', $metadata->asArray()[0]->groupName());
     }
 
+    #[TestDox('Parses #[IgnoreDeprecations] attribute on method')]
+    public function test_parses_IgnoreDeprecations_attribute_on_method(): void
+    {
+        $metadata = $this->parser()->forMethod(IgnoreDeprecationsMethodTest::class, 'testOne')->isIgnoreDeprecations();
+
+        $this->assertCount(1, $metadata);
+        $this->assertTrue($metadata->asArray()[0]->isIgnoreDeprecations());
+    }
+
+    #[TestDox('Parses #[IgnorePhpunitDeprecations] attribute on method')]
+    public function test_parses_IgnorePhpunitDeprecations_attribute_on_method(): void
+    {
+        $metadata = $this->parser()->forMethod(IgnorePhpunitDeprecationsMethodTest::class, 'testOne')->isIgnorePhpunitDeprecations();
+
+        $this->assertCount(1, $metadata);
+        $this->assertTrue($metadata->asArray()[0]->isIgnorePhpunitDeprecations());
+    }
+
     #[TestDox('Parses #[PostCondition] attribute on method')]
     public function test_parses_PostCondition_attribute_on_method(): void
     {
@@ -731,7 +796,7 @@ abstract class AttributeParserTestCase extends TestCase
 
         $this->assertTrue($requirement->isRequiresPhp());
 
-        assert($requirement instanceof \PHPUnit\Metadata\RequiresPhp);
+        assert($requirement instanceof RequiresPhp);
 
         $versionRequirement = $requirement->versionRequirement();
 
@@ -751,7 +816,7 @@ abstract class AttributeParserTestCase extends TestCase
 
         $this->assertTrue($requirement->isRequiresPhpExtension());
 
-        assert($requirement instanceof \PHPUnit\Metadata\RequiresPhpExtension);
+        assert($requirement instanceof RequiresPhpExtension);
 
         $this->assertSame('bar', $requirement->extension());
         $this->assertTrue($requirement->hasVersionRequirement());
@@ -770,7 +835,7 @@ abstract class AttributeParserTestCase extends TestCase
 
         $this->assertTrue($requirement->isRequiresPhpExtension());
 
-        assert($requirement instanceof \PHPUnit\Metadata\RequiresPhpExtension);
+        assert($requirement instanceof RequiresPhpExtension);
 
         $this->assertSame('baz', $requirement->extension());
         $this->assertTrue($requirement->hasVersionRequirement());
@@ -793,7 +858,7 @@ abstract class AttributeParserTestCase extends TestCase
 
         $this->assertTrue($requirement->isRequiresPhpunit());
 
-        assert($requirement instanceof \PHPUnit\Metadata\RequiresPhpunit);
+        assert($requirement instanceof RequiresPhpunit);
 
         $versionRequirement = $requirement->versionRequirement();
 
@@ -813,7 +878,7 @@ abstract class AttributeParserTestCase extends TestCase
 
         $this->assertTrue($requirement->isRequiresSetting());
 
-        assert($requirement instanceof \PHPUnit\Metadata\RequiresSetting);
+        assert($requirement instanceof RequiresSetting);
 
         $this->assertSame('another-setting', $requirement->setting());
         $this->assertSame('another-value', $requirement->value());
@@ -855,6 +920,20 @@ abstract class AttributeParserTestCase extends TestCase
         $this->assertCount(1, $metadata);
         $this->assertTrue($metadata->asArray()[0]->isTestWith());
         $this->assertSame([1, 2, 3], $metadata->asArray()[0]->data());
+        $this->assertFalse($metadata->asArray()[0]->hasName());
+        $this->assertNull($metadata->asArray()[0]->name());
+    }
+
+    #[TestDox('Parses #[TestWith] attribute with name on method')]
+    public function test_parses_TestWith_attribute_with_name_on_method(): void
+    {
+        $metadata = $this->parser()->forMethod(TestWithTest::class, 'testOneWithName')->isTestWith();
+
+        $this->assertCount(1, $metadata);
+        $this->assertTrue($metadata->asArray()[0]->isTestWith());
+        $this->assertSame([1, 2, 3], $metadata->asArray()[0]->data());
+        $this->assertTrue($metadata->asArray()[0]->hasName());
+        $this->assertSame('Name1', $metadata->asArray()[0]->name());
     }
 
     #[TestDox('Parses #[TestWithJson] attribute on method')]
@@ -865,6 +944,20 @@ abstract class AttributeParserTestCase extends TestCase
         $this->assertCount(1, $metadata);
         $this->assertTrue($metadata->asArray()[0]->isTestWith());
         $this->assertSame([1, 2, 3], $metadata->asArray()[0]->data());
+        $this->assertFalse($metadata->asArray()[0]->hasName());
+        $this->assertNull($metadata->asArray()[0]->name());
+    }
+
+    #[TestDox('Parses #[TestWithJson] attribute with name on method')]
+    public function test_parses_TestWithJson_attribute_with_name_on_method(): void
+    {
+        $metadata = $this->parser()->forMethod(TestWithTest::class, 'testTwoWithName')->isTestWith();
+
+        $this->assertCount(1, $metadata);
+        $this->assertTrue($metadata->asArray()[0]->isTestWith());
+        $this->assertSame([1, 2, 3], $metadata->asArray()[0]->data());
+        $this->assertTrue($metadata->asArray()[0]->hasName());
+        $this->assertSame('Name2', $metadata->asArray()[0]->name());
     }
 
     #[TestDox('Parses #[Ticket] attribute on method')]
