@@ -1235,6 +1235,26 @@ final class BuilderTest extends TestCase
         $configuration->failOnDeprecation();
     }
 
+    #[TestDox('--fail-on-phpunit-deprecation')]
+    public function testFailOnPhpunitDeprecation(): void
+    {
+        $configuration = (new Builder)->fromParameters(['--fail-on-phpunit-deprecation']);
+
+        $this->assertTrue($configuration->hasFailOnPhpunitDeprecation());
+        $this->assertTrue($configuration->failOnPhpunitDeprecation());
+    }
+
+    public function testFailOnPhpunitDeprecationMayNotBeConfigured(): void
+    {
+        $configuration = (new Builder)->fromParameters([]);
+
+        $this->assertFalse($configuration->hasFailOnPhpunitDeprecation());
+
+        $this->expectException(Exception::class);
+
+        $configuration->failOnPhpunitDeprecation();
+    }
+
     #[TestDox('--fail-on-empty-test-suite')]
     public function testFailOnEmptyTestSuite(): void
     {
@@ -1971,6 +1991,26 @@ final class BuilderTest extends TestCase
         $configuration->displayDetailsOnTestsThatTriggerDeprecations();
     }
 
+    #[TestDox('--display-phpunit-deprecations')]
+    public function testDisplayPhpunitDeprecations(): void
+    {
+        $configuration = (new Builder)->fromParameters(['--display-phpunit-deprecations']);
+
+        $this->assertTrue($configuration->hasDisplayDetailsOnPhpunitDeprecations());
+        $this->assertTrue($configuration->displayDetailsOnPhpunitDeprecations());
+    }
+
+    public function testDisplayPhpunitDeprecationsMayNotBeConfigured(): void
+    {
+        $configuration = (new Builder)->fromParameters([]);
+
+        $this->assertFalse($configuration->hasDisplayDetailsOnPhpunitDeprecations());
+
+        $this->expectException(Exception::class);
+
+        $configuration->displayDetailsOnPhpunitDeprecations();
+    }
+
     #[TestDox('--display-errors')]
     public function testDisplayErrors(): void
     {
